pub struct ImageHandle {
pub image: SkImage,
pub bytes: Bytes,
}Expand description
A decoded image shared by reference, ready to be rendered by an image().
Fields
image: SkImagebytes: BytesBacking data of the [SkImage], kept alive for as long as the image is used.
Implementations